@@ -59,10 +59,7 @@ PcaLocantore.default <- function(x, k=0, kmax=ncol(x), delta = 0.001, na.action
     ##
     ## verify and set the input parameters: k and kmax
     ##
-    ##
-    ## verify and set the input parameters: k and kmax
-    ##
-    kmax <- max(min(floor(kmax), floor(n/2), rankMM(x)),1)
+    kmax <- max(min(floor(kmax), rankMM(x)),1)
     if((k <- floor(k)) < 0)
         k <- 0
     else if(k > kmax) {
@@ -107,7 +104,7 @@ PcaLocantore.default <- function(x, k=0, kmax=ncol(x), delta = 0.001, na.action
 
     ##out = princomp(y, scores = TRUE, cor = FALSE, na.action=na.action, subset = TRUE)
     ## no scaling - we have already scaled with MAD
-    out = PcaClassic(y, scale=FALSE, signflip=signflip, ...)
+    out = PcaClassic(y, k=k, kmax=kmax, scale=FALSE, signflip=signflip, ...)
 
     k <- out@k
     scores = data %*% out@loadings
